
import React, { useEffect } from 'react';
import { useHistory } from 'react-router-dom';
import { Space } from 'dingtalk-design-mobile';
import MyList from '../MyList';
import { dateFormat, getUpdateStr, searchTitle } from '../../utils/utility';
import { label, resourcePool_1, resourcePool_2 } from '../../assets/cardImg';
import routerStatus from '../../status/router';

const ResourcePoolList = ({ search, data, hasMore, getScrollTopKey, scrollTop, searchValue, modalData, getResourcePoolData }) => {
  const history = useHistory();

  // 加载更多数据
  function handleLoadMore(callback) {
    getResourcePoolData({ ...search, page: search.page + 1 }, '', callback);
  }

  //列表更新
  useEffect(() => {
    if (routerStatus.spinPage['resourcePool']) {
      getResourcePoolData({ ...search, page: 1, size: search.page * search.size }, 'spin');
      routerStatus.setPageScrollTopNow('resourcePool');
      routerStatus.clearSpinPage('resourcePool');
    }
  }, [routerStatus.spinPage['resourcePool']]);

  return (
    <MyList
      data={data}
      hasMore={hasMore}
      bottomText={'已加载全部数据'}
      loadMore={handleLoadMore}
      getScrollTopKey={getScrollTopKey}
      scrollTop={scrollTop}
      itemDom={(item, index) => {
        return (
          <div
            className="building-card-bottom"
            style={index === 0 ? { marginTop: 0 } : null}
            key={index}
          >
            <div className='cardFollow-card'>
              <div style={{ display: "flex", justifyContent: 'space-between' }}>
                <Space style={{ '--gap': '8px' }}>
                  <div className="cardFollow-title">{item.personName || '-'}</div>
                  {
                    item.markNum > 0 &&
                    <div className="cardFollow-label" onClick={() => history.push(`/socialSecurityCard/markInfo?idcard=${item.idcard}&personName=${item.personName}`)}> <img style={{ width: '16px' }} src={label} alt="" />{item.markNum + '条标记信息'}</div>
                  }
                </Space>
                <div><span className='cardFollow-label-grey'>未申领</span></div>
              </div>
              <div className="cardFollow-dashed"></div>
              <div onClick={() => modalData(item)}>
                <Space direction='vertical' style={{ '--gap': '8px' }}>
                  <div className="cardFollow-main">
                    <div className='cardFollow-main-title'>身份证号：</div>
                    <div className="cardFollow-main-text">{item.idcard}</div>
                  </div>
                  <div className="cardFollow-main">
                    <div className='cardFollow-main-title'>联系电话：</div>
                    <div className="cardFollow-main-text">{item.contact}</div>
                  </div>
                  <div className="cardFollow-main">
                    <div className='cardFollow-main-title'>通讯地址：</div>
                    <div className="cardFollow-main-text">{item.houseaddress}</div>
                  </div>
                </Space>

              </div>
              <div className="cardFollow-dashed"></div>
              <div className="resourcePool-foot">
                {
                  item.applyFlair === null ?
                    <div className="resourcePool-foot-right">-</div> :
                    <>
                      <div className="resourcePool-foot-left">
                        {
                          (item.applyFlair === 0 || item.applyFlair === 1) &&
                          <img style={{ width: '16px' }} src={item.applyFlair === 1 ? resourcePool_1 : resourcePool_2} alt="" />
                        }
                      </div>
                      <div className="resourcePool-foot-right">
                        <div className="resourcePool-foot-right-title">{item.applyFlair === 1 ? '符合制卡条件' : item.applyFlair === 0 ? '不符合制卡条件' : '-'}</div>
                      </div>
                    </>
                }
              </div>
            </div>
          </div>
        );
      }}
    />
  );
};

export default ResourcePoolList;
